@@ -8,11 +8,14 @@ OC.L10N.register(
     "News feeds" : "Uudisvood",
     "Unread articles" : "Lugemata artiklid",
     "News" : "Uudised",
-    "News folders" : "Uudiste kataloogid",
+    "News folders" : "Uudiste kaustad",
     "News articles" : "Uudiste artiklid",
     "Shared with me" : "Jagatud minuga",
-    "Download" : "Lae alla",
+    "An RSS/Atom feed reader" : "RSS/Atom uudisvoogude lugeja",
+    "Download" : "Laadi alla",
     "Close" : "Sulge",
+    "Internal server error!" : "Serveri sisemine viga!",
+    "Unknown error!" : "Tundmatu viga!",
     "Web address" : "Veebiaadress",
     "No folder" : "Kausta pole",
     "Folder name" : "Kausta nimi",
@@ -22,17 +25,29 @@ OC.L10N.register(
     "New folder" : "Uus kaust",
     "Folder exists already!" : "Kaust on juba olemas!",
     "Credentials" : "Kasutajatunnused",
+    "Auto discover Feed" : "Tuvasta uudisvoog automaatselt",
     "Subscribe" : "Telli",
     "Maximum read count per feed" : "Maksimaalne lugemiste arv voo kohta",
     "Maximum redirects" : "Maksimaalsed ümbersuunamised",
     "Feed fetcher timeout" : "Voo ühenduse aegumine",
     "Explore Service URL" : "Sirvi teenuse URL-i",
+    "Update interval" : "Uuendamise välp",
     "Use system cron for updates" : "Kasuta süsteemi croni uuendusteks",
     "Delete unread articles automatically" : "Kustuta automaatselt lugemata artiklid",
+    "Article list" : "Artiklite loend",
+    "Article details" : "Artikli üksikasjad",
     "Move" : "Liiguta",
+    "User Name" : "Kasutajanimi",
     "Share" : "Jaga",
+    "Share with {num} users" : "Jaga {num} kasutajaga",
+    "Compact" : "Kompaktne",
     "Vertical" : "Vertikaalne",
     "Horizontal" : "Horisontaalne",
+    "Please select a valid OPML file" : "Palun vali korrektne opml-fail",
+    "Error uploading the opml file" : "Viga opml-faili üleslaadimisel",
+    "Error retrieving the opml file" : "Viga opml-faili laadimisel",
+    "Rename Folder" : "Muuda kausta nime",
+    "Are you sure you want to delete?" : "Kas oled kindel, et tahad kustutada?",
     "Mark read" : "Märgi loetuks",
     "All articles" : "Kõik artiklid",
     "Starred" : "Tärniga märgitud",
@@ -43,8 +58,12 @@ OC.L10N.register(
     "Disable mark read through scrolling" : "Lülita kerimisel loetuks määramine välja",
     "Show all articles" : "Näita kõiki artikleid",
     "Reverse ordering (oldest on top)" : "Pööratud järjestus (vanemad eespool)",
-    "Rename" : "Nimeta ümber",
+    "Rename" : "Muuda nime",
     "Delete" : "Kustuta",
+    "Rename Feed" : "Muuda uudisvoo nime",
+    "Open Feed URL" : "Ava uudisvoo võrguaadress",
+    "Unpin from top" : "Lõpeta esiletõstmine",
+    "Pin to top" : "Tõsta esile",
     "Newest first" : "Uuemad eespool",
     "Oldest first" : "Vanemad eespool",
     "Default order" : "Vaikejärjestus",
@@ -56,6 +75,7 @@ OC.L10N.register(
     "Play audio" : "Esita heli",
     "Download audio" : "Laadi helifail alla",
     "Download video" : "Laadi video alla",
+    "{num} seconds" : "{num} sekundit",
     "Open website" : "Ava veebisait",
     "Keep article unread" : "Hoia kui lugemata",
     "Toggle keep current article unread" : "Lülita 'hoia olemasolev artikkel lugemata'",
@@ -70,8 +90,8 @@ OC.L10N.register(
     "Refresh" : "Värskenda",
     "Load next feed" : "Laadi järgmine voog",
     "Load previous feed" : "Kaadi eelmine voog",
-    "Load previous folder" : "Laadi eelmine kataloog",
-    "Load next folder" : "Laadi järgmine kataloog",
+    "Load previous folder" : "Laadi eelmine kaust",
+    "Load next folder" : "Laadi järgmine kaust",
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax või webcron aktiveeritud! Su voogusid ei uuendata!",
     "How to set up the operating system cron" : "Kuidas seadistada operatsioonisüsteemi ajastatud tegevust",
     "No articles available" : "Ühtegi artiklit pole saadaval",
