@@ -9,11 +9,13 @@ OC.L10N.register(
     "New folder" : "Täze papka döretmek",
     "Move" : "Göçüriň",
     "Share" : "Paýlaş",
+    "Default" : "Bellenen",
     "Settings" : "Sazlamalar",
     "Rename" : "Adyny üýtgetmek",
     "Delete" : "Pozmak",
     "Newest first" : "Täze ilkinji",
     "Oldest first" : "Ilki bilen iň köne",
+    "Not available" : "Elýeterli däl",
     "Refresh" : "Täzelemek",
     "Create" : "Dörediň",
     "Dismiss" : "Ýapmak.",
